@@ -1613,8 +1613,10 @@ pidgin_account_dialog_show(PidginAccountDialogType type,
 	gtk_widget_show(dbox);
 	add_proxy_options(dialog, dbox);
 
+#ifdef USE_CLOSE_AND_CANCEL_BUTTONS 
 	/* Cancel button */
 	pidgin_dialog_add_button(GTK_DIALOG(win), GTK_STOCK_CANCEL, G_CALLBACK(cancel_account_prefs_cb), dialog);
+#endif /* USE_CLOSE_AND_CANCEL_BUTTONS  */
 
 	/* Save button */
 	button = pidgin_dialog_add_button(GTK_DIALOG(win),
@@ -1956,8 +1958,13 @@ close_accounts_cb(GtkWidget *w, AccountsWindow *dialog)
 	pidgin_accounts_window_hide();
 }
 
-
-#if !HILDON_CHECK_VERSION(2,1,0)
+#define ACCOUNTS_LIST_HAS_ENABLED
+#ifdef USE_HILDON
+#	if HILDON_CHECK_VERSION(2,1,0)
+#		undef ACCOUNTS_LIST_HAS_ENABLED
+#	endif /* HILDON < 2.1.0 */
+#endif /* USE_HILDON */
+#ifdef ACCOUNTS_LIST_HAS_ENABLED
 static void
 enabled_cb(GtkCellRendererToggle *renderer, gchar *path_str,
 			   gpointer data)
@@ -1987,7 +1994,7 @@ enabled_cb(GtkCellRendererToggle *renderer, gchar *path_str,
 
 	purple_account_set_enabled(account, PIDGIN_UI, !enabled);
 }
-#endif /* HILDON < 2.1.0 */
+#endif /* ACCOUNTS_LIST_HAS_ENABLED */
 
 static void
 add_columns(GtkWidget *treeview, AccountsWindow *dialog)
@@ -1995,7 +2002,7 @@ add_columns(GtkWidget *treeview, AccountsWindow *dialog)
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
-#if !HILDON_CHECK_VERSION(2,1,0)
+#ifdef ACCOUNTS_LIST_HAS_ENABLED
 	/* Enabled */
 	renderer = gtk_cell_renderer_toggle_new();
 
@@ -2007,7 +2014,7 @@ add_columns(GtkWidget *treeview, AccountsWindow *dialog)
 
 	gtk_tree_view_column_set_resizable(column, FALSE);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
-#endif /* HILDON < 2.1.0 */
+#endif /* ACCOUNTS_LIST_HAS_ENABLED */
 
 	/* Username column */
 	column = gtk_tree_view_column_new();
@@ -2382,8 +2389,10 @@ pidgin_accounts_window_show(void)
 	dialog->delete_button = button;
 	gtk_widget_set_sensitive(button, FALSE);
 
+#ifdef USE_CLOSE_AND_CANCEL_BUTTONS
 	/* Close button */
 	pidgin_dialog_add_button(GTK_DIALOG(win), GTK_STOCK_CLOSE, G_CALLBACK(close_accounts_cb), dialog);
+#endif /* USE_CLOSE_AND_CANCEL_BUTTONS */
 
 	purple_signal_connect(pidgin_account_get_handle(), "account-modified",
 	                    accounts_window,
