@@ -309,9 +309,9 @@ pidgin_ui_init(void)
 	pidgin_xfers_init();
 	pidgin_roomlist_init();
 	pidgin_log_init();
-#if (!defined(USE_HILDON) || HILDON_CHECK_VERSION(1,0,0))
+#ifdef USE_DOCKLET
 	pidgin_docklet_init();
-#endif /* vanilla or HILDON >= 1.0.0 */
+#endif /* USE_DOCKLET */
 	pidgin_smileys_init();
 	pidgin_utils_init();
 	pidgin_medias_init();
@@ -334,9 +334,9 @@ pidgin_quit(void)
 	pidgin_smileys_uninit();
 	pidgin_conversations_uninit();
 	pidgin_status_uninit();
-#if (!defined(USE_HILDON) || HILDON_CHECK_VERSION(1,0,0))
+#ifdef USE_DOCKLET
 	pidgin_docklet_uninit();
-#endif /* vanilla or HILDON >= 1.0.0 */
+#endif /* USE_DOCKLET */
 	pidgin_blist_uninit();
 	pidgin_connection_uninit();
 	pidgin_account_uninit();
